#include "ecdb.h"

Ecdb_Project *
ecdb_project_new(void)
{
	Ecdb_Project *proj;

	proj = calloc(1, sizeof(Ecdb_Project));
	if (!proj)
		return NULL;
	if (!ecdb_project_init(proj))
	{
		FREE(proj);
		return NULL;
	}
	
	return proj;
}

int
ecdb_project_init(Ecdb_Project *proj)
{
	return TRUE;
}

void
ecdb_project_destroy(Ecdb_Project *proj)
{
	free(proj);
}

void
ecdb_project_type_set(Ecdb_Project *proj, unsigned int t)
{
	proj->type = t;
}

int
ecdb_shutdown(void *data, int type, void *event)
{
	if (em->drives)
		ecore_list_destroy(em->drives);
	free(em);
	
	if (!ecore_file_recursive_rm("/tmp/ecdb"))
		printf("Removal of temporary directory failed!\n");
	ecore_main_loop_quit();
	return FALSE;
}

void
ecdb_burn_init(void)
{
	burn_initialize();
	burn_msgs_set_severities("NEVER", "SORRY", "ecdb: ");
	burn_set_signal_handling("ecdb: ", NULL, 0);
}

void
ecdb_image_init(void)
{
	iso_init();
	iso_set_msgs_severities("NEVER", "SORRY", "ecdb: ");
}

