#ifndef ECDB_MISC_H
#define ECDB_MISC_H

Ecdb_Project 	*ecdb_project_new(void);
int 		 ecdb_project_init(Ecdb_Project *proj);
void		 ecdb_project_destroy(Ecdb_Project *proj);
void		 ecdb_project_type_set(Ecdb_Project *proj, unsigned int t);
void		 ecdb_projects_free(void *data);
int 		 ecdb_shutdown(void *data, int type, void *event);
void 		 ecdb_burn_init(void);
void 		 ecdb_image_init(void);

#endif
